// $Id: zxcomm.h 35 2006-06-29 23:39:02Z Don Kinzer $
#ifndef __ZXCOMM_H_INCLUDED__
#define __ZXCOMM_H_INCLUDED__

#include <windows.h>
//#define CALLBACK	WINAPI

#ifdef __cplusplus
extern "C"
{
#endif

// definitions for 'flags' of ZXDownloadEx()
#define ZX_DOWNLOAD_WRITE			0x0001		// download the image
#define ZX_DOWNLOAD_VERIFY			0x0002		// perform verification after download
#define ZX_DOWNLOAD_IDENTIFY		0x0004		// display device firmware version before download
#define ZX_DOWNLOAD_CONFIG			0x0100		// downloading configuration information

// definitions for 'flags' of ZXUpdateEx()
#define ZX_UPDATE_NORMAL			0x0000
#define ZX_UPDATE_NO_BLINK			0x0001		// don't blink LEDs (ZX-24 only)
#define ZX_UPDATE_EMERGENCY			0x0002		// perform emergency update

#define ZX_MODE_MASK				0x00ff
#define ZX_COMM_HANDLE				0x1000		// 'port' is actually a HANDLE
#define ZX_NO_RESET					0x2000		// don't reset the device
#define ZX_IGNORE_HWND_RET			0x4000		// ignore the return value from window message

// return values for ZXDownloadEx() and ZXUpdateEx()
#define ZX_SUCCESS					0
#define ZX_PARAMETER_ERROR			1			// invalid parameter value supplied
#define ZX_ERROR_FILE_OPEN			2			// could not open the specified file
#define ZX_INVALID_DOWNLOAD_FILE	3			// download file not in expected format
#define ZX_INVALID_UPDATE_FILE		4			// update file not in expected format or failed integrity check
#define ZX_CANT_OPEN_PORT			5			// attempt to open COM port failed
#define ZX_FAILED_SPEED_CHANGE		6			// attempt to change COM speed failed
#define ZX_NO_ATN_REPSONSE			7			// device failed to respond to ATN
#define ZX_RETRY_LIMIT_EXCEEDED		8			// record transmission failed after multiple retries (update only)
#define ZX_COMM_TIMEOUT				9			// no response from device for record transmission
#define ZX_VERSION_TIMEOUT			10			// no response from device for firmware version check
#define ZX_VERSION_FAILURE			11			// device firmware version too old
#define ZX_RECORD_NAK				12			// device sent negative acknowledgement
#define ZX_BAD_RESPONSE				13			// device sent unexpected response
#define ZX_ABORTED					14			// process aborted due to response from callback
#define ZX_ALLOC_ERROR				15			// memory allocation error
#define ZX_BAD_CONFIG_DATA			16

#define DL_SPEED				CBR_115200
#define STD_SPEED				CBR_19200

typedef void (CALLBACK *MesgFunc)(const char *, long);
typedef WORD (CALLBACK *ProgFunc)(long, long, long, long);

// exported entry points
int CALLBACK ZXDownload(const char *file, long port, long flags, ProgFunc progFunc, long progData);
int CALLBACK ZXDownloadEx(const char *file, long port, long flags, ProgFunc progFunc, long progData, MesgFunc mesgFunc, long mesgData);

int CALLBACK ZXUpdate(const char *file, long port, long flags, ProgFunc progFunc, long progData);
int CALLBACK ZXUpdateEx(const char *file, long port, long flags, ProgFunc progFunc, long progData, MesgFunc mesgFunc, long mesgData);

int CALLBACK ZXConfigure(const char *cfgData, long cfgLen, long port, long flags, MesgFunc mesgFunc, long mesgData);
int CALLBACK ZXIdentify(long port, long flags, MesgFunc mesgFunc, long mesgData);

int CALLBACK ZXDownloadWnd(const char *file, long port, long flags, HWND hWnd, UINT mesg, long lParam);
int CALLBACK ZXUpdateWnd(const char *file, long port, long flags, HWND hWnd, UINT mesg, long lParam);

// public entry points
void atn(HANDLE hand, WORD onTime);
void clearQueue(HANDLE hand);
int commInit(unsigned port, HANDLE *handp);
int doAtn(HANDLE hand, int needResp);
void doReset(HANDLE cHand);
BYTE hexVal(BYTE c);
void msDelay(WORD ms);
void setDiagCode(int code);
int setSpeed(HANDLE hand, DWORD speed);
void usDelay(WORD us);

#ifdef __cplusplus
}
#endif

#endif	// __ZXCOMM_H_INCLUDED__
